<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  88011 => 'Citycell',
  88013 => 'Grameenphone',
  88014 => 'Banglalink',
  88015 => 'TeleTalk',
  88016 => 'Airtel',
  88017 => 'Grameenphone',
  88018 => 'Robi',
  88019 => 'Banglalink',
);
